# Black-Box-Package #

Obijetivo:
  Este pacote e utilizado para trabalhar com diferentes funcionalidade da dentro da AWS Amazon,
diferentes tipos de banco de dados e funçoes de tratamento de informação.

Dependencias:
  você necessita da versão python 3.6 ou mais recente e das seguintes bibliotecas:
    boto3==1.11.0
    pandas==0.25.1
    numpy==1.16.5
    pyarrow==0.15.1
    SQLAlchemy==1.3.15
    psycopg2==2.8.4
    psycopg2-binary==2.8.5
    workalendar==10.4.0
    cx-Oracle==8.0.1

